"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4483 import (
        AbstractAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4484 import (
        AbstractShaftCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4485 import (
        AbstractShaftOrHousingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4486 import (
        AbstractShaftToMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4487 import (
        AGMAGleasonConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4488 import (
        AGMAGleasonConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4489 import (
        AGMAGleasonConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4490 import (
        AssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4491 import (
        BearingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4492 import (
        BeltConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4493 import (
        BeltDriveCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4494 import (
        BevelDifferentialGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4495 import (
        BevelDifferentialGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4496 import (
        BevelDifferentialGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4497 import (
        BevelDifferentialPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4498 import (
        BevelDifferentialSunGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4499 import (
        BevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4500 import (
        BevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4501 import (
        BevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4502 import (
        BoltCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4503 import (
        BoltedJointCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4504 import (
        ClutchCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4505 import (
        ClutchConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4506 import (
        ClutchHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4507 import (
        CoaxialConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4508 import (
        ComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4509 import (
        ConceptCouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4510 import (
        ConceptCouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4511 import (
        ConceptCouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4512 import (
        ConceptGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4513 import (
        ConceptGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4514 import (
        ConceptGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4515 import (
        ConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4516 import (
        ConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4517 import (
        ConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4518 import (
        ConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4519 import (
        ConnectorCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4520 import (
        CouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4521 import (
        CouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4522 import (
        CouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4523 import (
        CVTBeltConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4524 import (
        CVTCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4525 import (
        CVTPulleyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4526 import (
        CycloidalAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4527 import (
        CycloidalDiscCentralBearingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4528 import (
        CycloidalDiscCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4529 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4530 import (
        CylindricalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4531 import (
        CylindricalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4532 import (
        CylindricalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4533 import (
        CylindricalPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4534 import (
        DatumCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4535 import (
        ExternalCADModelCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4536 import (
        FaceGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4537 import (
        FaceGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4538 import (
        FaceGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4539 import (
        FEPartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4540 import (
        FlexiblePinAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4541 import (
        GearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4542 import (
        GearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4543 import (
        GearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4544 import (
        GuideDxfModelCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4545 import (
        HypoidGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4546 import (
        HypoidGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4547 import (
        HypoidGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4548 import (
        InterMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4549 import (
        KlingelnbergCycloPalloidConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4550 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4551 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4552 import (
        KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4553 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4554 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4555 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4556 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4557 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4558 import (
        MassDiscCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4559 import (
        MeasurementComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4560 import (
        MicrophoneArrayCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4561 import (
        MicrophoneCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4562 import (
        MountableComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4563 import (
        OilSealCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4564 import (
        PartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4565 import (
        PartToPartShearCouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4566 import (
        PartToPartShearCouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4567 import (
        PartToPartShearCouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4568 import (
        PlanetaryConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4569 import (
        PlanetaryGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4570 import (
        PlanetCarrierCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4571 import (
        PointLoadCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4572 import (
        PowerLoadCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4573 import (
        PulleyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4574 import (
        RingPinsCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4575 import (
        RingPinsToDiscConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4576 import (
        RollingRingAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4577 import (
        RollingRingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4578 import (
        RollingRingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4579 import (
        RootAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4580 import (
        ShaftCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4581 import (
        ShaftHubConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4582 import (
        ShaftToMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4583 import (
        SpecialisedAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4584 import (
        SpiralBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4585 import (
        SpiralBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4586 import (
        SpiralBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4587 import (
        SpringDamperCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4588 import (
        SpringDamperConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4589 import (
        SpringDamperHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4590 import (
        StraightBevelDiffGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4591 import (
        StraightBevelDiffGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4592 import (
        StraightBevelDiffGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4593 import (
        StraightBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4594 import (
        StraightBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4595 import (
        StraightBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4596 import (
        StraightBevelPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4597 import (
        StraightBevelSunGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4598 import (
        SynchroniserCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4599 import (
        SynchroniserHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4600 import (
        SynchroniserPartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4601 import (
        SynchroniserSleeveCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4602 import (
        TorqueConverterCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4603 import (
        TorqueConverterConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4604 import (
        TorqueConverterPumpCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4605 import (
        TorqueConverterTurbineCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4606 import (
        UnbalancedMassCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4607 import (
        VirtualComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4608 import (
        WormGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4609 import (
        WormGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4610 import (
        WormGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4611 import (
        ZerolBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4612 import (
        ZerolBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4613 import (
        ZerolBevelGearSetCompoundPowerFlow,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.power_flows.compound._4483": [
            "AbstractAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4484": [
            "AbstractShaftCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4485": [
            "AbstractShaftOrHousingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4486": [
            "AbstractShaftToMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4487": [
            "AGMAGleasonConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4488": [
            "AGMAGleasonConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4489": [
            "AGMAGleasonConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4490": [
            "AssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4491": [
            "BearingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4492": [
            "BeltConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4493": [
            "BeltDriveCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4494": [
            "BevelDifferentialGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4495": [
            "BevelDifferentialGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4496": [
            "BevelDifferentialGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4497": [
            "BevelDifferentialPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4498": [
            "BevelDifferentialSunGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4499": [
            "BevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4500": [
            "BevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4501": [
            "BevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4502": [
            "BoltCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4503": [
            "BoltedJointCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4504": [
            "ClutchCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4505": [
            "ClutchConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4506": [
            "ClutchHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4507": [
            "CoaxialConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4508": [
            "ComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4509": [
            "ConceptCouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4510": [
            "ConceptCouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4511": [
            "ConceptCouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4512": [
            "ConceptGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4513": [
            "ConceptGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4514": [
            "ConceptGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4515": [
            "ConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4516": [
            "ConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4517": [
            "ConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4518": [
            "ConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4519": [
            "ConnectorCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4520": [
            "CouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4521": [
            "CouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4522": [
            "CouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4523": [
            "CVTBeltConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4524": [
            "CVTCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4525": [
            "CVTPulleyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4526": [
            "CycloidalAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4527": [
            "CycloidalDiscCentralBearingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4528": [
            "CycloidalDiscCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4529": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4530": [
            "CylindricalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4531": [
            "CylindricalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4532": [
            "CylindricalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4533": [
            "CylindricalPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4534": [
            "DatumCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4535": [
            "ExternalCADModelCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4536": [
            "FaceGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4537": [
            "FaceGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4538": [
            "FaceGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4539": [
            "FEPartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4540": [
            "FlexiblePinAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4541": [
            "GearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4542": [
            "GearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4543": [
            "GearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4544": [
            "GuideDxfModelCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4545": [
            "HypoidGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4546": [
            "HypoidGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4547": [
            "HypoidGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4548": [
            "InterMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4549": [
            "KlingelnbergCycloPalloidConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4550": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4551": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4552": [
            "KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4553": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4554": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4555": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4556": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4557": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4558": [
            "MassDiscCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4559": [
            "MeasurementComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4560": [
            "MicrophoneArrayCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4561": [
            "MicrophoneCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4562": [
            "MountableComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4563": [
            "OilSealCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4564": [
            "PartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4565": [
            "PartToPartShearCouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4566": [
            "PartToPartShearCouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4567": [
            "PartToPartShearCouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4568": [
            "PlanetaryConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4569": [
            "PlanetaryGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4570": [
            "PlanetCarrierCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4571": [
            "PointLoadCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4572": [
            "PowerLoadCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4573": [
            "PulleyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4574": [
            "RingPinsCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4575": [
            "RingPinsToDiscConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4576": [
            "RollingRingAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4577": [
            "RollingRingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4578": [
            "RollingRingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4579": [
            "RootAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4580": [
            "ShaftCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4581": [
            "ShaftHubConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4582": [
            "ShaftToMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4583": [
            "SpecialisedAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4584": [
            "SpiralBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4585": [
            "SpiralBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4586": [
            "SpiralBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4587": [
            "SpringDamperCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4588": [
            "SpringDamperConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4589": [
            "SpringDamperHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4590": [
            "StraightBevelDiffGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4591": [
            "StraightBevelDiffGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4592": [
            "StraightBevelDiffGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4593": [
            "StraightBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4594": [
            "StraightBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4595": [
            "StraightBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4596": [
            "StraightBevelPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4597": [
            "StraightBevelSunGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4598": [
            "SynchroniserCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4599": [
            "SynchroniserHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4600": [
            "SynchroniserPartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4601": [
            "SynchroniserSleeveCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4602": [
            "TorqueConverterCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4603": [
            "TorqueConverterConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4604": [
            "TorqueConverterPumpCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4605": [
            "TorqueConverterTurbineCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4606": [
            "UnbalancedMassCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4607": [
            "VirtualComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4608": [
            "WormGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4609": [
            "WormGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4610": [
            "WormGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4611": [
            "ZerolBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4612": [
            "ZerolBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4613": [
            "ZerolBevelGearSetCompoundPowerFlow"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundPowerFlow",
    "AbstractShaftCompoundPowerFlow",
    "AbstractShaftOrHousingCompoundPowerFlow",
    "AbstractShaftToMountableComponentConnectionCompoundPowerFlow",
    "AGMAGleasonConicalGearCompoundPowerFlow",
    "AGMAGleasonConicalGearMeshCompoundPowerFlow",
    "AGMAGleasonConicalGearSetCompoundPowerFlow",
    "AssemblyCompoundPowerFlow",
    "BearingCompoundPowerFlow",
    "BeltConnectionCompoundPowerFlow",
    "BeltDriveCompoundPowerFlow",
    "BevelDifferentialGearCompoundPowerFlow",
    "BevelDifferentialGearMeshCompoundPowerFlow",
    "BevelDifferentialGearSetCompoundPowerFlow",
    "BevelDifferentialPlanetGearCompoundPowerFlow",
    "BevelDifferentialSunGearCompoundPowerFlow",
    "BevelGearCompoundPowerFlow",
    "BevelGearMeshCompoundPowerFlow",
    "BevelGearSetCompoundPowerFlow",
    "BoltCompoundPowerFlow",
    "BoltedJointCompoundPowerFlow",
    "ClutchCompoundPowerFlow",
    "ClutchConnectionCompoundPowerFlow",
    "ClutchHalfCompoundPowerFlow",
    "CoaxialConnectionCompoundPowerFlow",
    "ComponentCompoundPowerFlow",
    "ConceptCouplingCompoundPowerFlow",
    "ConceptCouplingConnectionCompoundPowerFlow",
    "ConceptCouplingHalfCompoundPowerFlow",
    "ConceptGearCompoundPowerFlow",
    "ConceptGearMeshCompoundPowerFlow",
    "ConceptGearSetCompoundPowerFlow",
    "ConicalGearCompoundPowerFlow",
    "ConicalGearMeshCompoundPowerFlow",
    "ConicalGearSetCompoundPowerFlow",
    "ConnectionCompoundPowerFlow",
    "ConnectorCompoundPowerFlow",
    "CouplingCompoundPowerFlow",
    "CouplingConnectionCompoundPowerFlow",
    "CouplingHalfCompoundPowerFlow",
    "CVTBeltConnectionCompoundPowerFlow",
    "CVTCompoundPowerFlow",
    "CVTPulleyCompoundPowerFlow",
    "CycloidalAssemblyCompoundPowerFlow",
    "CycloidalDiscCentralBearingConnectionCompoundPowerFlow",
    "CycloidalDiscCompoundPowerFlow",
    "CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow",
    "CylindricalGearCompoundPowerFlow",
    "CylindricalGearMeshCompoundPowerFlow",
    "CylindricalGearSetCompoundPowerFlow",
    "CylindricalPlanetGearCompoundPowerFlow",
    "DatumCompoundPowerFlow",
    "ExternalCADModelCompoundPowerFlow",
    "FaceGearCompoundPowerFlow",
    "FaceGearMeshCompoundPowerFlow",
    "FaceGearSetCompoundPowerFlow",
    "FEPartCompoundPowerFlow",
    "FlexiblePinAssemblyCompoundPowerFlow",
    "GearCompoundPowerFlow",
    "GearMeshCompoundPowerFlow",
    "GearSetCompoundPowerFlow",
    "GuideDxfModelCompoundPowerFlow",
    "HypoidGearCompoundPowerFlow",
    "HypoidGearMeshCompoundPowerFlow",
    "HypoidGearSetCompoundPowerFlow",
    "InterMountableComponentConnectionCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow",
    "MassDiscCompoundPowerFlow",
    "MeasurementComponentCompoundPowerFlow",
    "MicrophoneArrayCompoundPowerFlow",
    "MicrophoneCompoundPowerFlow",
    "MountableComponentCompoundPowerFlow",
    "OilSealCompoundPowerFlow",
    "PartCompoundPowerFlow",
    "PartToPartShearCouplingCompoundPowerFlow",
    "PartToPartShearCouplingConnectionCompoundPowerFlow",
    "PartToPartShearCouplingHalfCompoundPowerFlow",
    "PlanetaryConnectionCompoundPowerFlow",
    "PlanetaryGearSetCompoundPowerFlow",
    "PlanetCarrierCompoundPowerFlow",
    "PointLoadCompoundPowerFlow",
    "PowerLoadCompoundPowerFlow",
    "PulleyCompoundPowerFlow",
    "RingPinsCompoundPowerFlow",
    "RingPinsToDiscConnectionCompoundPowerFlow",
    "RollingRingAssemblyCompoundPowerFlow",
    "RollingRingCompoundPowerFlow",
    "RollingRingConnectionCompoundPowerFlow",
    "RootAssemblyCompoundPowerFlow",
    "ShaftCompoundPowerFlow",
    "ShaftHubConnectionCompoundPowerFlow",
    "ShaftToMountableComponentConnectionCompoundPowerFlow",
    "SpecialisedAssemblyCompoundPowerFlow",
    "SpiralBevelGearCompoundPowerFlow",
    "SpiralBevelGearMeshCompoundPowerFlow",
    "SpiralBevelGearSetCompoundPowerFlow",
    "SpringDamperCompoundPowerFlow",
    "SpringDamperConnectionCompoundPowerFlow",
    "SpringDamperHalfCompoundPowerFlow",
    "StraightBevelDiffGearCompoundPowerFlow",
    "StraightBevelDiffGearMeshCompoundPowerFlow",
    "StraightBevelDiffGearSetCompoundPowerFlow",
    "StraightBevelGearCompoundPowerFlow",
    "StraightBevelGearMeshCompoundPowerFlow",
    "StraightBevelGearSetCompoundPowerFlow",
    "StraightBevelPlanetGearCompoundPowerFlow",
    "StraightBevelSunGearCompoundPowerFlow",
    "SynchroniserCompoundPowerFlow",
    "SynchroniserHalfCompoundPowerFlow",
    "SynchroniserPartCompoundPowerFlow",
    "SynchroniserSleeveCompoundPowerFlow",
    "TorqueConverterCompoundPowerFlow",
    "TorqueConverterConnectionCompoundPowerFlow",
    "TorqueConverterPumpCompoundPowerFlow",
    "TorqueConverterTurbineCompoundPowerFlow",
    "UnbalancedMassCompoundPowerFlow",
    "VirtualComponentCompoundPowerFlow",
    "WormGearCompoundPowerFlow",
    "WormGearMeshCompoundPowerFlow",
    "WormGearSetCompoundPowerFlow",
    "ZerolBevelGearCompoundPowerFlow",
    "ZerolBevelGearMeshCompoundPowerFlow",
    "ZerolBevelGearSetCompoundPowerFlow",
)



"""GearSetCompoundSteadyStateSynchronousResponse"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
    _3516,
)

_GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses.Compound",
    "GearSetCompoundSteadyStateSynchronousResponse",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
        _3341,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
        _3416,
        _3422,
        _3429,
        _3434,
        _3447,
        _3450,
        _3465,
        _3471,
        _3480,
        _3484,
        _3487,
        _3490,
        _3497,
        _3502,
        _3519,
        _3525,
        _3528,
        _3543,
        _3546,
    )

    Self = TypeVar("Self", bound="GearSetCompoundSteadyStateSynchronousResponse")
    CastSelf = TypeVar(
        "CastSelf",
        bound="GearSetCompoundSteadyStateSynchronousResponse._Cast_GearSetCompoundSteadyStateSynchronousResponse",
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearSetCompoundSteadyStateSynchronousResponse",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearSetCompoundSteadyStateSynchronousResponse:
    """Special nested class for casting GearSetCompoundSteadyStateSynchronousResponse to subclasses."""

    __parent__: "GearSetCompoundSteadyStateSynchronousResponse"

    @property
    def specialised_assembly_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3516.SpecialisedAssemblyCompoundSteadyStateSynchronousResponse":
        return self.__parent__._cast(
            _3516.SpecialisedAssemblyCompoundSteadyStateSynchronousResponse
        )

    @property
    def abstract_assembly_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3416.AbstractAssemblyCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3416,
        )

        return self.__parent__._cast(
            _3416.AbstractAssemblyCompoundSteadyStateSynchronousResponse
        )

    @property
    def part_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3497.PartCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3497,
        )

        return self.__parent__._cast(_3497.PartCompoundSteadyStateSynchronousResponse)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3422.AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3422,
        )

        return self.__parent__._cast(
            _3422.AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def bevel_differential_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3429.BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3429,
        )

        return self.__parent__._cast(
            _3429.BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def bevel_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3434.BevelGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3434,
        )

        return self.__parent__._cast(
            _3434.BevelGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def concept_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3447.ConceptGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3447,
        )

        return self.__parent__._cast(
            _3447.ConceptGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def conical_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3450.ConicalGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3450,
        )

        return self.__parent__._cast(
            _3450.ConicalGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def cylindrical_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3465.CylindricalGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3465,
        )

        return self.__parent__._cast(
            _3465.CylindricalGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def face_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3471.FaceGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3471,
        )

        return self.__parent__._cast(
            _3471.FaceGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def hypoid_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3480.HypoidGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3480,
        )

        return self.__parent__._cast(
            _3480.HypoidGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3484.KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3484,
        )

        return self.__parent__._cast(
            _3484.KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3487.KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3487,
        )

        return self.__parent__._cast(
            _3487.KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3490.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3490,
        )

        return self.__parent__._cast(
            _3490.KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def planetary_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3502.PlanetaryGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3502,
        )

        return self.__parent__._cast(
            _3502.PlanetaryGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def spiral_bevel_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3519.SpiralBevelGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3519,
        )

        return self.__parent__._cast(
            _3519.SpiralBevelGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def straight_bevel_diff_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3525.StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3525,
        )

        return self.__parent__._cast(
            _3525.StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def straight_bevel_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3528.StraightBevelGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3528,
        )

        return self.__parent__._cast(
            _3528.StraightBevelGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def worm_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3543.WormGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3543,
        )

        return self.__parent__._cast(
            _3543.WormGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def zerol_bevel_gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3546.ZerolBevelGearSetCompoundSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound import (
            _3546,
        )

        return self.__parent__._cast(
            _3546.ZerolBevelGearSetCompoundSteadyStateSynchronousResponse
        )

    @property
    def gear_set_compound_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "GearSetCompoundSteadyStateSynchronousResponse":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GearSetCompoundSteadyStateSynchronousResponse(
    _3516.SpecialisedAssemblyCompoundSteadyStateSynchronousResponse
):
    """GearSetCompoundSteadyStateSynchronousResponse

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_SET_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_3341.GearSetSteadyStateSynchronousResponse]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.GearSetSteadyStateSynchronousResponse]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_3341.GearSetSteadyStateSynchronousResponse]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses.GearSetSteadyStateSynchronousResponse]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_GearSetCompoundSteadyStateSynchronousResponse":
        """Cast to another type.

        Returns:
            _Cast_GearSetCompoundSteadyStateSynchronousResponse
        """
        return _Cast_GearSetCompoundSteadyStateSynchronousResponse(self)



"""BevelDifferentialPlanetGearCompoundHarmonicAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
    _6250,
)

_BEVEL_DIFFERENTIAL_PLANET_GEAR_COMPOUND_HARMONIC_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.Compound",
    "BevelDifferentialPlanetGearCompoundHarmonicAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
        _6036,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
        _6243,
        _6255,
        _6264,
        _6271,
        _6297,
        _6318,
        _6320,
    )

    Self = TypeVar("Self", bound="BevelDifferentialPlanetGearCompoundHarmonicAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="BevelDifferentialPlanetGearCompoundHarmonicAnalysis._Cast_BevelDifferentialPlanetGearCompoundHarmonicAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("BevelDifferentialPlanetGearCompoundHarmonicAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BevelDifferentialPlanetGearCompoundHarmonicAnalysis:
    """Special nested class for casting BevelDifferentialPlanetGearCompoundHarmonicAnalysis to subclasses."""

    __parent__: "BevelDifferentialPlanetGearCompoundHarmonicAnalysis"

    @property
    def bevel_differential_gear_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6250.BevelDifferentialGearCompoundHarmonicAnalysis":
        return self.__parent__._cast(
            _6250.BevelDifferentialGearCompoundHarmonicAnalysis
        )

    @property
    def bevel_gear_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6255.BevelGearCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6255,
        )

        return self.__parent__._cast(_6255.BevelGearCompoundHarmonicAnalysis)

    @property
    def agma_gleason_conical_gear_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6243.AGMAGleasonConicalGearCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6243,
        )

        return self.__parent__._cast(
            _6243.AGMAGleasonConicalGearCompoundHarmonicAnalysis
        )

    @property
    def conical_gear_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6271.ConicalGearCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6271,
        )

        return self.__parent__._cast(_6271.ConicalGearCompoundHarmonicAnalysis)

    @property
    def gear_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6297.GearCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6297,
        )

        return self.__parent__._cast(_6297.GearCompoundHarmonicAnalysis)

    @property
    def mountable_component_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6318.MountableComponentCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6318,
        )

        return self.__parent__._cast(_6318.MountableComponentCompoundHarmonicAnalysis)

    @property
    def component_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6264.ComponentCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6264,
        )

        return self.__parent__._cast(_6264.ComponentCompoundHarmonicAnalysis)

    @property
    def part_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6320.PartCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6320,
        )

        return self.__parent__._cast(_6320.PartCompoundHarmonicAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def bevel_differential_planet_gear_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "BevelDifferentialPlanetGearCompoundHarmonicAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class BevelDifferentialPlanetGearCompoundHarmonicAnalysis(
    _6250.BevelDifferentialGearCompoundHarmonicAnalysis
):
    """BevelDifferentialPlanetGearCompoundHarmonicAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BEVEL_DIFFERENTIAL_PLANET_GEAR_COMPOUND_HARMONIC_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_analysis_cases_ready(
        self: "Self",
    ) -> "List[_6036.BevelDifferentialPlanetGearHarmonicAnalysis]":
        """List[mastapy.system_model.analyses_and_results.harmonic_analyses.BevelDifferentialPlanetGearHarmonicAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def component_analysis_cases(
        self: "Self",
    ) -> "List[_6036.BevelDifferentialPlanetGearHarmonicAnalysis]":
        """List[mastapy.system_model.analyses_and_results.harmonic_analyses.BevelDifferentialPlanetGearHarmonicAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_BevelDifferentialPlanetGearCompoundHarmonicAnalysis":
        """Cast to another type.

        Returns:
            _Cast_BevelDifferentialPlanetGearCompoundHarmonicAnalysis
        """
        return _Cast_BevelDifferentialPlanetGearCompoundHarmonicAnalysis(self)



"""FEEntityGroupWithSelection"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
)

from mastapy._private import _0
from mastapy._private._internal import constructor, utility

_FE_ENTITY_GROUP_WITH_SELECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.FE", "FEEntityGroupWithSelection"
)

if TYPE_CHECKING:
    from typing import Any, Type

    from mastapy._private.system_model.fe import _2636, _2668

    Self = TypeVar("Self", bound="FEEntityGroupWithSelection")
    CastSelf = TypeVar(
        "CastSelf", bound="FEEntityGroupWithSelection._Cast_FEEntityGroupWithSelection"
    )

TGroup = TypeVar("TGroup")
TGroupContents = TypeVar("TGroupContents")

__docformat__ = "restructuredtext en"
__all__ = ("FEEntityGroupWithSelection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FEEntityGroupWithSelection:
    """Special nested class for casting FEEntityGroupWithSelection to subclasses."""

    __parent__: "FEEntityGroupWithSelection"

    @property
    def element_face_group_with_selection(
        self: "CastSelf",
    ) -> "_2636.ElementFaceGroupWithSelection":
        from mastapy._private.system_model.fe import _2636

        return self.__parent__._cast(_2636.ElementFaceGroupWithSelection)

    @property
    def node_group_with_selection(self: "CastSelf") -> "_2668.NodeGroupWithSelection":
        from mastapy._private.system_model.fe import _2668

        return self.__parent__._cast(_2668.NodeGroupWithSelection)

    @property
    def fe_entity_group_with_selection(
        self: "CastSelf",
    ) -> "FEEntityGroupWithSelection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class FEEntityGroupWithSelection(_0.APIBase, Generic[TGroup, TGroupContents]):
    """FEEntityGroupWithSelection

    This is a mastapy class.

    Generic Types:
        TGroup
        TGroupContents
    """

    TYPE: ClassVar["Type"] = _FE_ENTITY_GROUP_WITH_SELECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def group(self: "Self") -> "TGroup":
        """TGroup

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Group")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @exception_bridge
    def add_selection_to_group(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "AddSelectionToGroup")

    @exception_bridge
    def delete_group(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "DeleteGroup")

    @exception_bridge
    def select_items(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "SelectItems")

    @property
    def cast_to(self: "Self") -> "_Cast_FEEntityGroupWithSelection":
        """Cast to another type.

        Returns:
            _Cast_FEEntityGroupWithSelection
        """
        return _Cast_FEEntityGroupWithSelection(self)



"""DataFromMotorPackagePerSpeed"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item

_DATA_FROM_MOTOR_PACKAGE_PER_SPEED = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "DataFromMotorPackagePerSpeed",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private._internal.typing import PathLike

    from mastapy._private.system_model.analyses_and_results.static_loads import _7790

    Self = TypeVar("Self", bound="DataFromMotorPackagePerSpeed")
    CastSelf = TypeVar(
        "CastSelf",
        bound="DataFromMotorPackagePerSpeed._Cast_DataFromMotorPackagePerSpeed",
    )


__docformat__ = "restructuredtext en"
__all__ = ("DataFromMotorPackagePerSpeed",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_DataFromMotorPackagePerSpeed:
    """Special nested class for casting DataFromMotorPackagePerSpeed to subclasses."""

    __parent__: "DataFromMotorPackagePerSpeed"

    @property
    def data_from_motor_package_per_speed(
        self: "CastSelf",
    ) -> "DataFromMotorPackagePerSpeed":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class DataFromMotorPackagePerSpeed(_0.APIBase):
    """DataFromMotorPackagePerSpeed

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _DATA_FROM_MOTOR_PACKAGE_PER_SPEED

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def include(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "Include")

        if temp is None:
            return False

        return temp

    @include.setter
    @exception_bridge
    @enforce_parameter_types
    def include(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "Include", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def speed(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Speed")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Torque")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def torque_selector(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_float":
        """ListWithSelectedItem[float]"""
        temp = pythonnet_property_get(self.wrapped, "TorqueSelector")

        if temp is None:
            return 0.0

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_float",
        )(temp)

    @torque_selector.setter
    @exception_bridge
    @enforce_parameter_types
    def torque_selector(self: "Self", value: "float") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_float.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "TorqueSelector", value)

    @property
    @exception_bridge
    def data_per_mean_torque(
        self: "Self",
    ) -> "List[_7790.DataFromMotorPackagePerMeanTorque]":
        """List[mastapy.system_model.analyses_and_results.static_loads.DataFromMotorPackagePerMeanTorque]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DataPerMeanTorque")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_DataFromMotorPackagePerSpeed":
        """Cast to another type.

        Returns:
            _Cast_DataFromMotorPackagePerSpeed
        """
        return _Cast_DataFromMotorPackagePerSpeed(self)



"""ITDesignation"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_IT_DESIGNATION = python_net_import("SMT.MastaAPI.Bearings.Tolerances", "ITDesignation")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ITDesignation")
    CastSelf = TypeVar("CastSelf", bound="ITDesignation._Cast_ITDesignation")


__docformat__ = "restructuredtext en"
__all__ = ("ITDesignation",)


class ITDesignation(Enum):
    """ITDesignation

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _IT_DESIGNATION

    IT1 = 0
    IT2 = 1
    IT3 = 2
    IT4 = 3
    IT5 = 4
    IT6 = 5
    IT7 = 6
    IT8 = 7
    IT9 = 8
    IT10 = 9
    IT11 = 10
    IT12 = 11
    IT13 = 12
    IT14 = 13


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ITDesignation.__setattr__ = __enum_setattr
ITDesignation.__delattr__ = __enum_delattr



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.materials.efficiency._395 import BaffleLoss
    from mastapy._private.materials.efficiency._396 import BearingEfficiencyRatingMethod
    from mastapy._private.materials.efficiency._397 import CombinedResistiveTorque
    from mastapy._private.materials.efficiency._398 import IndependentPowerLoss
    from mastapy._private.materials.efficiency._399 import IndependentResistiveTorque
    from mastapy._private.materials.efficiency._400 import LoadAndSpeedCombinedPowerLoss
    from mastapy._private.materials.efficiency._401 import OilPumpDetail
    from mastapy._private.materials.efficiency._402 import OilPumpDriveType
    from mastapy._private.materials.efficiency._403 import OilPumpLossCalculationMethod
    from mastapy._private.materials.efficiency._404 import OilSealLossCalculationMethod
    from mastapy._private.materials.efficiency._405 import OilSealMaterialType
    from mastapy._private.materials.efficiency._406 import OilSealType
    from mastapy._private.materials.efficiency._407 import PowerLoss
    from mastapy._private.materials.efficiency._408 import ResistiveTorque
    from mastapy._private.materials.efficiency._409 import (
        WetClutchLossCalculationMethod,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.materials.efficiency._395": ["BaffleLoss"],
        "_private.materials.efficiency._396": ["BearingEfficiencyRatingMethod"],
        "_private.materials.efficiency._397": ["CombinedResistiveTorque"],
        "_private.materials.efficiency._398": ["IndependentPowerLoss"],
        "_private.materials.efficiency._399": ["IndependentResistiveTorque"],
        "_private.materials.efficiency._400": ["LoadAndSpeedCombinedPowerLoss"],
        "_private.materials.efficiency._401": ["OilPumpDetail"],
        "_private.materials.efficiency._402": ["OilPumpDriveType"],
        "_private.materials.efficiency._403": ["OilPumpLossCalculationMethod"],
        "_private.materials.efficiency._404": ["OilSealLossCalculationMethod"],
        "_private.materials.efficiency._405": ["OilSealMaterialType"],
        "_private.materials.efficiency._406": ["OilSealType"],
        "_private.materials.efficiency._407": ["PowerLoss"],
        "_private.materials.efficiency._408": ["ResistiveTorque"],
        "_private.materials.efficiency._409": ["WetClutchLossCalculationMethod"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BaffleLoss",
    "BearingEfficiencyRatingMethod",
    "CombinedResistiveTorque",
    "IndependentPowerLoss",
    "IndependentResistiveTorque",
    "LoadAndSpeedCombinedPowerLoss",
    "OilPumpDetail",
    "OilPumpDriveType",
    "OilPumpLossCalculationMethod",
    "OilSealLossCalculationMethod",
    "OilSealMaterialType",
    "OilSealType",
    "PowerLoss",
    "ResistiveTorque",
    "WetClutchLossCalculationMethod",
)



"""PartHarmonicAnalysisOfSingleExcitation"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7946

_PART_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation",
    "PartHarmonicAnalysisOfSingleExcitation",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7943
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
        _6111,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
        _6370,
        _6371,
        _6372,
        _6374,
        _6376,
        _6377,
        _6378,
        _6380,
        _6381,
        _6383,
        _6384,
        _6385,
        _6386,
        _6388,
        _6389,
        _6390,
        _6392,
        _6393,
        _6395,
        _6397,
        _6398,
        _6399,
        _6401,
        _6402,
        _6404,
        _6406,
        _6408,
        _6409,
        _6411,
        _6412,
        _6413,
        _6415,
        _6417,
        _6419,
        _6420,
        _6421,
        _6422,
        _6423,
        _6425,
        _6426,
        _6427,
        _6428,
        _6430,
        _6431,
        _6432,
        _6433,
        _6435,
        _6437,
        _6439,
        _6440,
        _6442,
        _6443,
        _6445,
        _6446,
        _6447,
        _6448,
        _6449,
        _6451,
        _6452,
        _6455,
        _6456,
        _6458,
        _6459,
        _6460,
        _6461,
        _6462,
        _6463,
        _6465,
        _6467,
        _6468,
        _6469,
        _6470,
        _6472,
        _6473,
        _6475,
        _6477,
        _6478,
        _6479,
        _6481,
        _6482,
        _6484,
        _6485,
        _6486,
        _6487,
        _6488,
        _6489,
        _6490,
        _6492,
        _6493,
        _6494,
        _6495,
        _6496,
        _6497,
        _6499,
        _6500,
        _6502,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses import _4988
    from mastapy._private.system_model.part_model import _2743

    Self = TypeVar("Self", bound="PartHarmonicAnalysisOfSingleExcitation")
    CastSelf = TypeVar(
        "CastSelf",
        bound="PartHarmonicAnalysisOfSingleExcitation._Cast_PartHarmonicAnalysisOfSingleExcitation",
    )


__docformat__ = "restructuredtext en"
__all__ = ("PartHarmonicAnalysisOfSingleExcitation",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PartHarmonicAnalysisOfSingleExcitation:
    """Special nested class for casting PartHarmonicAnalysisOfSingleExcitation to subclasses."""

    __parent__: "PartHarmonicAnalysisOfSingleExcitation"

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def abstract_assembly_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6370.AbstractAssemblyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6370,
        )

        return self.__parent__._cast(
            _6370.AbstractAssemblyHarmonicAnalysisOfSingleExcitation
        )

    @property
    def abstract_shaft_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6371.AbstractShaftHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6371,
        )

        return self.__parent__._cast(
            _6371.AbstractShaftHarmonicAnalysisOfSingleExcitation
        )

    @property
    def abstract_shaft_or_housing_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6372.AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6372,
        )

        return self.__parent__._cast(
            _6372.AbstractShaftOrHousingHarmonicAnalysisOfSingleExcitation
        )

    @property
    def agma_gleason_conical_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6374.AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6374,
        )

        return self.__parent__._cast(
            _6374.AGMAGleasonConicalGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def agma_gleason_conical_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6376.AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6376,
        )

        return self.__parent__._cast(
            _6376.AGMAGleasonConicalGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def assembly_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6377.AssemblyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6377,
        )

        return self.__parent__._cast(_6377.AssemblyHarmonicAnalysisOfSingleExcitation)

    @property
    def bearing_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6378.BearingHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6378,
        )

        return self.__parent__._cast(_6378.BearingHarmonicAnalysisOfSingleExcitation)

    @property
    def belt_drive_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6380.BeltDriveHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6380,
        )

        return self.__parent__._cast(_6380.BeltDriveHarmonicAnalysisOfSingleExcitation)

    @property
    def bevel_differential_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6381.BevelDifferentialGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6381,
        )

        return self.__parent__._cast(
            _6381.BevelDifferentialGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def bevel_differential_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6383.BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6383,
        )

        return self.__parent__._cast(
            _6383.BevelDifferentialGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def bevel_differential_planet_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6384.BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6384,
        )

        return self.__parent__._cast(
            _6384.BevelDifferentialPlanetGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def bevel_differential_sun_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6385.BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6385,
        )

        return self.__parent__._cast(
            _6385.BevelDifferentialSunGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def bevel_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6386.BevelGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6386,
        )

        return self.__parent__._cast(_6386.BevelGearHarmonicAnalysisOfSingleExcitation)

    @property
    def bevel_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6388.BevelGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6388,
        )

        return self.__parent__._cast(
            _6388.BevelGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def bolted_joint_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6389.BoltedJointHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6389,
        )

        return self.__parent__._cast(
            _6389.BoltedJointHarmonicAnalysisOfSingleExcitation
        )

    @property
    def bolt_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6390.BoltHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6390,
        )

        return self.__parent__._cast(_6390.BoltHarmonicAnalysisOfSingleExcitation)

    @property
    def clutch_half_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6392.ClutchHalfHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6392,
        )

        return self.__parent__._cast(_6392.ClutchHalfHarmonicAnalysisOfSingleExcitation)

    @property
    def clutch_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6393.ClutchHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6393,
        )

        return self.__parent__._cast(_6393.ClutchHarmonicAnalysisOfSingleExcitation)

    @property
    def component_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6395.ComponentHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6395,
        )

        return self.__parent__._cast(_6395.ComponentHarmonicAnalysisOfSingleExcitation)

    @property
    def concept_coupling_half_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6397.ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6397,
        )

        return self.__parent__._cast(
            _6397.ConceptCouplingHalfHarmonicAnalysisOfSingleExcitation
        )

    @property
    def concept_coupling_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6398.ConceptCouplingHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6398,
        )

        return self.__parent__._cast(
            _6398.ConceptCouplingHarmonicAnalysisOfSingleExcitation
        )

    @property
    def concept_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6399.ConceptGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6399,
        )

        return self.__parent__._cast(
            _6399.ConceptGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def concept_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6401.ConceptGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6401,
        )

        return self.__parent__._cast(
            _6401.ConceptGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def conical_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6402.ConicalGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6402,
        )

        return self.__parent__._cast(
            _6402.ConicalGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def conical_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6404.ConicalGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6404,
        )

        return self.__parent__._cast(
            _6404.ConicalGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def connector_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6406.ConnectorHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6406,
        )

        return self.__parent__._cast(_6406.ConnectorHarmonicAnalysisOfSingleExcitation)

    @property
    def coupling_half_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6408.CouplingHalfHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6408,
        )

        return self.__parent__._cast(
            _6408.CouplingHalfHarmonicAnalysisOfSingleExcitation
        )

    @property
    def coupling_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6409.CouplingHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6409,
        )

        return self.__parent__._cast(_6409.CouplingHarmonicAnalysisOfSingleExcitation)

    @property
    def cvt_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6411.CVTHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6411,
        )

        return self.__parent__._cast(_6411.CVTHarmonicAnalysisOfSingleExcitation)

    @property
    def cvt_pulley_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6412.CVTPulleyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6412,
        )

        return self.__parent__._cast(_6412.CVTPulleyHarmonicAnalysisOfSingleExcitation)

    @property
    def cycloidal_assembly_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6413.CycloidalAssemblyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6413,
        )

        return self.__parent__._cast(
            _6413.CycloidalAssemblyHarmonicAnalysisOfSingleExcitation
        )

    @property
    def cycloidal_disc_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6415.CycloidalDiscHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6415,
        )

        return self.__parent__._cast(
            _6415.CycloidalDiscHarmonicAnalysisOfSingleExcitation
        )

    @property
    def cylindrical_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6417.CylindricalGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6417,
        )

        return self.__parent__._cast(
            _6417.CylindricalGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def cylindrical_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6419.CylindricalGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6419,
        )

        return self.__parent__._cast(
            _6419.CylindricalGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def cylindrical_planet_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6420.CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6420,
        )

        return self.__parent__._cast(
            _6420.CylindricalPlanetGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def datum_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6421.DatumHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6421,
        )

        return self.__parent__._cast(_6421.DatumHarmonicAnalysisOfSingleExcitation)

    @property
    def external_cad_model_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6422.ExternalCADModelHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6422,
        )

        return self.__parent__._cast(
            _6422.ExternalCADModelHarmonicAnalysisOfSingleExcitation
        )

    @property
    def face_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6423.FaceGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6423,
        )

        return self.__parent__._cast(_6423.FaceGearHarmonicAnalysisOfSingleExcitation)

    @property
    def face_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6425.FaceGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6425,
        )

        return self.__parent__._cast(
            _6425.FaceGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def fe_part_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6426.FEPartHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6426,
        )

        return self.__parent__._cast(_6426.FEPartHarmonicAnalysisOfSingleExcitation)

    @property
    def flexible_pin_assembly_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6427.FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6427,
        )

        return self.__parent__._cast(
            _6427.FlexiblePinAssemblyHarmonicAnalysisOfSingleExcitation
        )

    @property
    def gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6428.GearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6428,
        )

        return self.__parent__._cast(_6428.GearHarmonicAnalysisOfSingleExcitation)

    @property
    def gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6430.GearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6430,
        )

        return self.__parent__._cast(_6430.GearSetHarmonicAnalysisOfSingleExcitation)

    @property
    def guide_dxf_model_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6431.GuideDxfModelHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6431,
        )

        return self.__parent__._cast(
            _6431.GuideDxfModelHarmonicAnalysisOfSingleExcitation
        )

    @property
    def hypoid_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6433.HypoidGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6433,
        )

        return self.__parent__._cast(_6433.HypoidGearHarmonicAnalysisOfSingleExcitation)

    @property
    def hypoid_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6435.HypoidGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6435,
        )

        return self.__parent__._cast(
            _6435.HypoidGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6437.KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6437,
        )

        return self.__parent__._cast(
            _6437.KlingelnbergCycloPalloidConicalGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> (
        "_6439.KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation"
    ):
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6439,
        )

        return self.__parent__._cast(
            _6439.KlingelnbergCycloPalloidConicalGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6440.KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6440,
        )

        return self.__parent__._cast(
            _6440.KlingelnbergCycloPalloidHypoidGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> (
        "_6442.KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation"
    ):
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6442,
        )

        return self.__parent__._cast(
            _6442.KlingelnbergCycloPalloidHypoidGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6443.KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6443,
        )

        return self.__parent__._cast(
            _6443.KlingelnbergCycloPalloidSpiralBevelGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6445.KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6445,
        )

        return self.__parent__._cast(
            _6445.KlingelnbergCycloPalloidSpiralBevelGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def mass_disc_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6446.MassDiscHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6446,
        )

        return self.__parent__._cast(_6446.MassDiscHarmonicAnalysisOfSingleExcitation)

    @property
    def measurement_component_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6447.MeasurementComponentHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6447,
        )

        return self.__parent__._cast(
            _6447.MeasurementComponentHarmonicAnalysisOfSingleExcitation
        )

    @property
    def microphone_array_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6448.MicrophoneArrayHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6448,
        )

        return self.__parent__._cast(
            _6448.MicrophoneArrayHarmonicAnalysisOfSingleExcitation
        )

    @property
    def microphone_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6449.MicrophoneHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6449,
        )

        return self.__parent__._cast(_6449.MicrophoneHarmonicAnalysisOfSingleExcitation)

    @property
    def mountable_component_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6451.MountableComponentHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6451,
        )

        return self.__parent__._cast(
            _6451.MountableComponentHarmonicAnalysisOfSingleExcitation
        )

    @property
    def oil_seal_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6452.OilSealHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6452,
        )

        return self.__parent__._cast(_6452.OilSealHarmonicAnalysisOfSingleExcitation)

    @property
    def part_to_part_shear_coupling_half_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6455.PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6455,
        )

        return self.__parent__._cast(
            _6455.PartToPartShearCouplingHalfHarmonicAnalysisOfSingleExcitation
        )

    @property
    def part_to_part_shear_coupling_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6456.PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6456,
        )

        return self.__parent__._cast(
            _6456.PartToPartShearCouplingHarmonicAnalysisOfSingleExcitation
        )

    @property
    def planetary_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6458.PlanetaryGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6458,
        )

        return self.__parent__._cast(
            _6458.PlanetaryGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def planet_carrier_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6459.PlanetCarrierHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6459,
        )

        return self.__parent__._cast(
            _6459.PlanetCarrierHarmonicAnalysisOfSingleExcitation
        )

    @property
    def point_load_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6460.PointLoadHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6460,
        )

        return self.__parent__._cast(_6460.PointLoadHarmonicAnalysisOfSingleExcitation)

    @property
    def power_load_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6461.PowerLoadHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6461,
        )

        return self.__parent__._cast(_6461.PowerLoadHarmonicAnalysisOfSingleExcitation)

    @property
    def pulley_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6462.PulleyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6462,
        )

        return self.__parent__._cast(_6462.PulleyHarmonicAnalysisOfSingleExcitation)

    @property
    def ring_pins_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6463.RingPinsHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6463,
        )

        return self.__parent__._cast(_6463.RingPinsHarmonicAnalysisOfSingleExcitation)

    @property
    def rolling_ring_assembly_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6465.RollingRingAssemblyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6465,
        )

        return self.__parent__._cast(
            _6465.RollingRingAssemblyHarmonicAnalysisOfSingleExcitation
        )

    @property
    def rolling_ring_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6467.RollingRingHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6467,
        )

        return self.__parent__._cast(
            _6467.RollingRingHarmonicAnalysisOfSingleExcitation
        )

    @property
    def root_assembly_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6468.RootAssemblyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6468,
        )

        return self.__parent__._cast(
            _6468.RootAssemblyHarmonicAnalysisOfSingleExcitation
        )

    @property
    def shaft_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6469.ShaftHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6469,
        )

        return self.__parent__._cast(_6469.ShaftHarmonicAnalysisOfSingleExcitation)

    @property
    def shaft_hub_connection_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6470.ShaftHubConnectionHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6470,
        )

        return self.__parent__._cast(
            _6470.ShaftHubConnectionHarmonicAnalysisOfSingleExcitation
        )

    @property
    def specialised_assembly_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6472.SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6472,
        )

        return self.__parent__._cast(
            _6472.SpecialisedAssemblyHarmonicAnalysisOfSingleExcitation
        )

    @property
    def spiral_bevel_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6473.SpiralBevelGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6473,
        )

        return self.__parent__._cast(
            _6473.SpiralBevelGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def spiral_bevel_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6475.SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6475,
        )

        return self.__parent__._cast(
            _6475.SpiralBevelGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def spring_damper_half_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6477.SpringDamperHalfHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6477,
        )

        return self.__parent__._cast(
            _6477.SpringDamperHalfHarmonicAnalysisOfSingleExcitation
        )

    @property
    def spring_damper_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6478.SpringDamperHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6478,
        )

        return self.__parent__._cast(
            _6478.SpringDamperHarmonicAnalysisOfSingleExcitation
        )

    @property
    def straight_bevel_diff_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6479.StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6479,
        )

        return self.__parent__._cast(
            _6479.StraightBevelDiffGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def straight_bevel_diff_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6481.StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6481,
        )

        return self.__parent__._cast(
            _6481.StraightBevelDiffGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def straight_bevel_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6482.StraightBevelGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6482,
        )

        return self.__parent__._cast(
            _6482.StraightBevelGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def straight_bevel_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6484.StraightBevelGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6484,
        )

        return self.__parent__._cast(
            _6484.StraightBevelGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def straight_bevel_planet_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6485.StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6485,
        )

        return self.__parent__._cast(
            _6485.StraightBevelPlanetGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def straight_bevel_sun_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6486.StraightBevelSunGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6486,
        )

        return self.__parent__._cast(
            _6486.StraightBevelSunGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def synchroniser_half_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6487.SynchroniserHalfHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6487,
        )

        return self.__parent__._cast(
            _6487.SynchroniserHalfHarmonicAnalysisOfSingleExcitation
        )

    @property
    def synchroniser_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6488.SynchroniserHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6488,
        )

        return self.__parent__._cast(
            _6488.SynchroniserHarmonicAnalysisOfSingleExcitation
        )

    @property
    def synchroniser_part_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6489.SynchroniserPartHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6489,
        )

        return self.__parent__._cast(
            _6489.SynchroniserPartHarmonicAnalysisOfSingleExcitation
        )

    @property
    def synchroniser_sleeve_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6490.SynchroniserSleeveHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6490,
        )

        return self.__parent__._cast(
            _6490.SynchroniserSleeveHarmonicAnalysisOfSingleExcitation
        )

    @property
    def torque_converter_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6492.TorqueConverterHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6492,
        )

        return self.__parent__._cast(
            _6492.TorqueConverterHarmonicAnalysisOfSingleExcitation
        )

    @property
    def torque_converter_pump_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6493.TorqueConverterPumpHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6493,
        )

        return self.__parent__._cast(
            _6493.TorqueConverterPumpHarmonicAnalysisOfSingleExcitation
        )

    @property
    def torque_converter_turbine_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6494.TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6494,
        )

        return self.__parent__._cast(
            _6494.TorqueConverterTurbineHarmonicAnalysisOfSingleExcitation
        )

    @property
    def unbalanced_mass_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6495.UnbalancedMassHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6495,
        )

        return self.__parent__._cast(
            _6495.UnbalancedMassHarmonicAnalysisOfSingleExcitation
        )

    @property
    def virtual_component_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6496.VirtualComponentHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6496,
        )

        return self.__parent__._cast(
            _6496.VirtualComponentHarmonicAnalysisOfSingleExcitation
        )

    @property
    def worm_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6497.WormGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6497,
        )

        return self.__parent__._cast(_6497.WormGearHarmonicAnalysisOfSingleExcitation)

    @property
    def worm_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6499.WormGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6499,
        )

        return self.__parent__._cast(
            _6499.WormGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def zerol_bevel_gear_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6500.ZerolBevelGearHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6500,
        )

        return self.__parent__._cast(
            _6500.ZerolBevelGearHarmonicAnalysisOfSingleExcitation
        )

    @property
    def zerol_bevel_gear_set_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6502.ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6502,
        )

        return self.__parent__._cast(
            _6502.ZerolBevelGearSetHarmonicAnalysisOfSingleExcitation
        )

    @property
    def part_harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "PartHarmonicAnalysisOfSingleExcitation":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PartHarmonicAnalysisOfSingleExcitation(_7946.PartStaticLoadAnalysisCase):
    """PartHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PART_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2743.Part":
        """mastapy.system_model.part_model.Part

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def harmonic_analysis_options(self: "Self") -> "_6111.HarmonicAnalysisOptions":
        """mastapy.system_model.analyses_and_results.harmonic_analyses.HarmonicAnalysisOptions

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "HarmonicAnalysisOptions")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def harmonic_analysis_of_single_excitation(
        self: "Self",
    ) -> "_6432.HarmonicAnalysisOfSingleExcitation":
        """mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation.HarmonicAnalysisOfSingleExcitation

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "HarmonicAnalysisOfSingleExcitation"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def uncoupled_modal_analysis(self: "Self") -> "_4988.PartModalAnalysis":
        """mastapy.system_model.analyses_and_results.modal_analyses.PartModalAnalysis

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "UncoupledModalAnalysis")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_PartHarmonicAnalysisOfSingleExcitation":
        """Cast to another type.

        Returns:
            _Cast_PartHarmonicAnalysisOfSingleExcitation
        """
        return _Cast_PartHarmonicAnalysisOfSingleExcitation(self)
